Команды управления доменами — СпамоБорец: документация

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- API СпамоБорца »

# Команды управления доменами

## Команда sf.domain.list

Получить список свойств домена.

### Авторизация

Требуется, партнерская.

### Параметры

`partner`
  Partner партнерская авторизация

`domain`
  Domain домен, свойства которого мы хотим получить (необязательный)

### Результат

`propreties`
  `Array(string)` список имен свойств домена

### Пример

#### JSON-RPC

    {"service":null,"method":"sf.domain.children","id":4,"params":[{"partner":null,"domain":"comment"}]}

    {"result": {"properties": ["storage", "model", "messageAnalyzer", "messageLog"]}, "id": 4}

## Команда sf.domain.get

Получить подробную информацию о свойстве домена.

### Авторизация

Требуется, партнерская.

### Параметры

`partner`
  Partner партнерская авторизация

`domain`
  Domain домен, свойства которого мы хотим получить (необязательный)

`name`
  `string` имя свойства домена

### Результат

`repr`
  `string` некоторое строковое представление свойства домена

`interfaces`
  `Array(string)` список интерфейсов, которые поддерживает свойство домена

`classname`
  `string` класс (тип) свойства домена

### Пример

#### JSON-RPC

    {"service":null,"method":"sf.domain.get","id":7,"params":[{"partner":null,"name":"storage"}]}

    {
     "result":
         {
             "classname": "DomainMemoryStorage",
             "interfaces": ["IExpirableStorage", "IUnreliableStorage", "IDomainBindable"],
             "repr": "<spamfighter.core.storage.memory.DomainMemoryStorage object at 0x2cd0cd0>"
          },
     "id": 7
    }

## Команда sf.domain.children

Получить список имен поддоменов указанного домена.

### Авторизация

Требуется, партнерская.

### Параметры

`partner`
  Partner партнерская авторизация

`domain`
  Domain домен, свойства которого мы хотим получить (необязательный)

### Результат

`children`
  `Array(string)` список имен поддоменов укзанного домена

### Пример

#### JSON-RPC

    {"service":null,"method":"sf.domain.children","id":2,"params":[{"partner":null}]}

    {"result": {"children": ["comment", "chat", "pm"]}, "id": 2}

### Navigation

- index
- next |
- previous |
- СпамоБорец: документация »
- API СпамоБорца »